# ppw0810


<p align="center">
<a href="https://pypi.python.org/pypi/ppw0810">
    <img src="https://img.shields.io/pypi/v/ppw0810.svg"
        alt = "Release Status">
</a>

<a href="https://github.com/zillionare/ppw0810/actions">
    <img src="https://github.com/zillionare/ppw0810/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">
</a>

<a href="https://zillionare.github.io/ppw0810/">
    <img src="https://img.shields.io/website/https/zillionare.github.io/ppw0810/index.html.svg?label=docs&down_message=unavailable&up_message=available" alt="Documentation Status">
</a>

</p>


Skeleton project created by Python Project Wizard (ppw)


* Free software: MIT
* Documentation: <https://zillionare.github.io/ppw0810/>


## Features

* TODO

## Credits

This package was created with the [ppw](https://zillionare.github.io/python-project-wizard) tool. For more information, please visit the [project page](https://zillionare.github.io/python-project-wizard/).
